@@ -1,5 +1,6 @@
 from time import sleep
-from . import caput, caget
+from epics import caget
+from . import caput
 
 def writeChannels(chanInfo):
     '''
